@@ -13,7 +13,7 @@ use English;
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -388,7 +388,13 @@ L<Error::Pure>.
 
 =head1 SEE ALSO
 
-L<Data::Random>.
+=over
+
+=item L<Data::Random>
+
+Perl module to generate random data
+
+=back
 
 =head1 REPOSITORY
 
@@ -402,11 +408,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © Michal Špaček 2013-2014
+ © Michal Špaček 2013-2015
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
